<!DOCTYPE html>
<html>

<head>
  <title>{{ config.html_title }}</title>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
</head>

<body>
  <script>
    const url = new URL(window.location.href);
    const targets = [
      '{{ config.mini18n_basepath }}',
      '{{ config.mini18n_basepath }}/index.html',
    ];
    if (targets.includes(url.pathname)) {
      url.pathname = '{{ config.mini18n_basepath }}{{ config.mini18n_default_language }}/';
      location.href = url.href;
    }
  </script>

  <noscript>
  </noscript>
</body>

</html>
